@@ -25,6 +25,7 @@
 
 #include <string.h>
 
+#include <camel/camel-i18n.h>
 #include <camel/camel-provider.h>
 #include <camel/camel-session.h>
 #include <camel/camel-url.h>
@@ -73,6 +74,10 @@ CamelProviderConfEntry exchange_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter", NULL,
 	  /* i18n: copy from evolution:camel-imap-provider.c */
 	  N_("Apply filters to new messages in Inbox on this server"), "0" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter_junk", NULL,
+	  N_("Check new messages for Junk contents"), "0" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "filter_junk_inbox", "filter_junk",
+	  N_("Only check for Junk messages in the Inbox folder"), "0" },
 	{ CAMEL_PROVIDER_CONF_END }
 };
 
@@ -143,6 +148,7 @@ camel_provider_module_init (void)
 	exchange_provider.auto_detect = exchange_auto_detect_cb;
 
 	bindtextdomain (GETTEXT_PACKAGE, CONNECTOR_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	exchange_provider.translation_domain = GETTEXT_PACKAGE;
 
 	camel_provider_register (&exchange_provider);
